=========
Spade-BDI
=========


.. image:: https://img.shields.io/pypi/v/spade_bdi.svg
        :target: https://pypi.python.org/pypi/spade_bdi

.. image:: https://img.shields.io/travis/sfp932705/spade_bdi.svg
        :target: https://travis-ci.org/sfp932705/spade_bdi

.. image:: https://readthedocs.org/projects/spade-bdi/badge/?version=latest
        :target: https://spade-bdi.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/sfp932705/spade_bdi/shield.svg
     :target: https://pyup.io/repos/github/sfp932705/spade_bdi/
     :alt: Updates



Implement BDI Agents based on the SPADE MAS Platform


* Free software: GNU General Public License v3
* Documentation: https://spade-bdi.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
